/**
 * CITIZEN Android Label Print SDK
 * Copyright(C) 2016-2017 CITIZEN SYSTEMS JAPAN CO., LTD. All Rights Reserved.
 */
package com.citizen.sdk.labelprint;

import com.citizen.csjlabellib.LibBase.LibPrinter;

import android.content.Context;
import android.hardware.usb.UsbDevice;

/**
 * Label print control class
 * @version 1.02
 */
public class LabelPrinter extends LibPrinter {

	public LabelPrinter() {
	}

	/**
	 * This method is used to the USB connection and the search printer.
	 * @param context : Context (android.content.Context)
	 * @return Return value
	 */
	public int setContext(Context context) {
		return super.setContext(context);
	}

	/**
	 * Gets a numerical value for the version number of this library.
	 * @return Version code
	 */
	public int getVersionCode() {
		return super.getVersionCode();
	}

	/**
	 * Gets a string for the version number of this library.
	 * @return Version Name
	 */
	public String getVersionName() {
		return super.getVersionName();
	}

	/**
	 * Connects to a printer.
	 * @param connectType : Connect type
	 * @param addr : IP address to connect or Bluetooth device address or Bluetooth device name
	 * @return Return value
	 */
	public int connect(int connectType, String addr) {
		return super.connect(connectType, addr);
	}

	/**
	 * Connects to a printer.
	 * @param connectType : Connect type
	 * @param addr : IP address to connect or Bluetooth device address or Bluetooth device name
	 * @param port : Connection port numberc
	 * @return Return value
	 */
	public int connect(int connectType, String addr, int port) {
		return super.connect(connectType, addr, port);
	}

	/**
	 * Connects to a printer.
	 * @param connectType : Connect type
	 * @param addr :IP address to connect or Bluetooth device address or Bluetooth device name
	 * @param port : Connection port number
	 * @param timeout : Timeout (msec)
	 * @return Return value
	 */
	public int connect(int connectType, String addr, int port, int timeout) {
		return super.connect(connectType, addr, port, timeout);
	}

	/**
	 * Connects to a printer.
	 * @param connectType : Connect type
	 * @param device : UsbDevice class (android.hardware.usb.UsbDevice)
	 * @return Return value
	 */
	public int connect(int connectType, UsbDevice device) {
		return super.connect(connectType, device);
	}

	/**
	 * Disconnects a printer.
	 * @return Return value
	 */
	public int disconnect() {
		return super.disconnect();
	}

	/**
	 * Gets the status of the printer and stores information into the properties.
	 * @return Return value
	 */
	public int printerCheck() {
		return super.printerCheck();
	}

	/**
	 * Sends binary data to a printer.
	 * @param data : Send data
	 * @return Return value
	 */
	public int sendData(byte[] data) {
		return super.sendData(data);
	}

	/**
	 * Prints labels by sending a label design created in the LabelDesign class.
	 * @param design : Design data
	 * @param quantity : Quantity
	 * @return Return value
	 */
	public int print(LabelDesign design, int quantity) {
		return super.print(design, quantity);
	}

	/**
	 * Stores a bitmap image into the flash memory.
	 * @param filePath :
	 * @param name :
	 * @param rotation :
	 * @param width :
	 * @param height :
	 * @return Return value
	 */
	public int storeNVBitmap(String filePath, String name, int rotation, int width, int height) {
		return super.storeNVBitmap(filePath, name, rotation, width, height);
	}

	/**
	 * Clears data in the print buffer.
	 * @return Return value
	 */
	public int clearOutput() {
		return super.clearOutput();
	}

	/**
	 * Searches available Citizen printers and obtains a list of printer addresses.
	 * @param ifType : Connect type
	 * @param searchTime : Search time
	 * @param status : Error code
	 * @return Return value
	 */
	public String[] searchLabelPrinter(int ifType, int searchTime, int[] status)
	{
		return super.searchLabelPrinter(ifType, searchTime, status);
	}

	/**
	 * Searches available Citizen printers and obtains a list of printer information.
	 * @param ifType : Connect type
	 * @param searchTime : Search time
	 * @param status : Error code
	 * @return Return value
	 */
	public CitizenPrinterInfo[] searchCitizenPrinter(int ifType, int searchTime, int[] status)
	{
		return super.searchCitizenPrinter(ifType, searchTime, status);
	}

	/**
	 * Sets the logging function.
	 * @param mode : Logging mode
	 * @param path : File path to store
	 * @param maxSize : Maximum Log Size
	 */
	public void setLog(int mode, String path, int maxSize)
	{
		super.setLog(mode, path, maxSize);
	}

	/**
	 * Sets the horizontal dot size.
	 * @param horizontalMagnification : Horizontal magnification
	 * @return Return value
	 */
	public int setHorizontalMagnification(int horizontalMagnification)
	{
		return super.setHorizontalMagnification(horizontalMagnification);
	}
	/**
	 * Gets the horizontal dot size.
	 * @return Horizontal magnification
	 */
	public int getHorizontalMagnification()
	{
		return super.getHorizontalMagnification();
	}

	/**
	 * Sets the vertical dot size.
	 * @param verticalMagnification : Vertical magnification
	 * @return Return value
	 */
	public int setVerticalMagnification(int verticalMagnification)
	{
		return super.setVerticalMagnification(verticalMagnification);
	}
	/**
	 * Gets the vertical dot size.
	 * @return Vertical magnification
	 */
	public int getVerticalMagnification()
	{
		return super.getVerticalMagnification();
	}

	/**
	 * Specifies how to print the area where multiple objects are overlapped.
	 * @param formatAttribute : Format attribute
	 * @return Return value
	 */
	public int setFormatAttribute(int formatAttribute)
	{
		return super.setFormatAttribute(formatAttribute);
	}
	/**
	 * Gets how to print the area where multiple objects are overlapped.
	 * @return Format attribute
	 */
	public int getFormatAttribute()
	{
		return super.getFormatAttribute();
	}

	/**
	 * Sets a paper length for continuous paper.
	 * @param continuousMediaLength : Continuous media length
	 * @return Return value
	 */
	public int setContinuousMediaLength(int continuousMediaLength)
	{
		return super.setContinuousMediaLength(continuousMediaLength);
	}
	/**
	 * Gets a paper length for continuous paper.
	 * @return Continuous media length
	 */
	public int getContinuousMediaLength()
	{
		return super.getContinuousMediaLength();
	}

	/**
	 * Sets the measurement unit.
	 * @param measurementUnit : Measurement unit
	 * @return Return value
	 */
	public int setMeasurementUnit(int measurementUnit)
	{
		return super.setMeasurementUnit(measurementUnit);
	}
	/**
	 * Gets the measurement unit.
	 * @return Measurement unit
	 */
	public int getMeasurementUnit()
	{
		return super.getMeasurementUnit();
	}

	/**
	 * Sets the print speed.
	 * @param printSpeed : Print speed
	 * @return Return value
	 */
	public int setPrintSpeed(int printSpeed)
	{
		return super.setPrintSpeed(printSpeed);
	}
	/**
	 * Gets the print speed.
	 * @return Print speed
	 */
	public int getPrintSpeed()
	{
		return super.getPrintSpeed();
	}

	/**
	 * Sets the feed speed.
	 * @param feedSpeed : Feed speed
	 * @return Return value
	 */
	public int setFeedSpeed(int feedSpeed)
	{
		return super.setFeedSpeed(feedSpeed);
	}
	/**
	 * Gets the feed speed.
	 * @return  Feed speed
	 */
	public int getFeedSpeed()
	{
		return super.getFeedSpeed();
	}

	/**
	 * Sets the slew speed.
	 * @param slewSpeed : Slew speed
	 * @return Return value
	 */
	public int setSlewSpeed(int slewSpeed)
	{
		return super.setSlewSpeed(slewSpeed);
	}
	/**
	 * Gets the slew speed.
	 * @return Slew speed
	 */
	public int getSlewSpeed()
	{
		return super.getSlewSpeed();
	}

	/**
	 * Sets the backup speed.
	 * @param backupSpeed : Backup speed
	 * @return Return value
	 */
	public int setBackupSpeed(int backupSpeed)
	{
		return super.setBackupSpeed(backupSpeed);
	}
	/**
	 * Gets the backup speed.
	 * @return Backup speed
	 */
	public int getBackupSpeed()
	{
		return super.getBackupSpeed();
	}

	/**
	 * Sets the print density.
	 * @param printDarkness : Print darkness
	 * @return Return value
	 */
	public int setPrintDarkness(int printDarkness)
	{
		return super.setPrintDarkness(printDarkness);
	}
	/**
	 * Gets the print density.
	 * @return Print darkness
	 */
	public int getPrintDarkness()
	{
		return super.getPrintDarkness();
	}

	/**
	 * Sets the double heat option.
	 * @param doubleHeat : Double heat
	 * @return Return value
	 */
	public int setDoubleHeat(int doubleHeat)
	{
		return super.setDoubleHeat(doubleHeat);
	}
	/**
	 * Gets the double heat option.
	 * @return Double heat
	 */
	public int getDoubleHeat()
	{
		return super.getDoubleHeat();
	}

	/**
	 * Sets the vertical offset to adjust the vertical printing position on the paper.
	 * @param offset : Vertical offset
	 * @return Return value
	 */
	public int setVerticalOffset(int verticalOffset)
	{
		return super.setVerticalOffset(verticalOffset);
	}
	/**
	 * Gets the vertical offset to adjust the vertical printing position on the paper.
	 * @return Vertical offset
	 */
	public int getVerticalOffset()
	{
		return super.getVerticalOffset();
	}

	/**
	 * Sets the horizontal offset to adjust the horizontal printing position on the paper.
	 * @param offset : Horizontal offset
	 * @return Return value
	 */
	public int setHorizontalOffset(int horizontalOffset)
	{
		return super.setHorizontalOffset(horizontalOffset);
	}
	/**
	 * Gets the horizontal offset to adjust the horizontal printing position on the paper.
	 * @return Horizontal offset
	 */
	public int getHorizontalOffset()
	{
		return super.getHorizontalOffset();
	}

	/**
	 * Sets the way how to handle media after printing.
	 * @param mediaHandling : Media handling
	 * @return Return value
	 */
	public int setMediaHandling(int mediaHandling)
	{
		return super.setMediaHandling(mediaHandling);
	}
	/**
	 * Gets the way how to handle media after printing.
	 * @return Media handling
	 */
	public int getMediaHandling()
	{
		return super.getMediaHandling();
	}

	/**
	 * Specifies the distance between paper sensor and print head to change the print starting position.
	 * @param startOffset : Start offset
	 * @return Return value
	 */
	public int setStartOffset(int startOffset)
	{
		return super.setStartOffset(startOffset);
	}
	/**
	 * Gets the distance between paper sensor and print head to change the print starting position.
	 * @return Start offset
	 */
	public int getStartOffset()
	{
		return super.getStartOffset();
	}

	/**
	 * Specifies the distance between paper sensor and cutter or peeler to change the print stop position.
	 * @param stopOffset : Stop offset
	 * @return Return value
	 */
	public int setStopOffset(int stopOffset)
	{
		return super.setStopOffset(stopOffset);
	}
	/**
	 * Gets the distance between paper sensor and cutter or peeler to change the print stop position.
	 * @return Stop offset
	 */
	public int getStopOffset()
	{
		return super.getStopOffset();
	}

	/**
	 * Sets the label sensor type.
	 * @param labelSensor : Label sensor
	 * @return Return value
	 */
	public int setLabelSensor(int labelSensor)
	{
		return super.setLabelSensor(labelSensor);
	}
	/**
	 * Gets the label sensor type.
	 * @return Label sensor
	 */
	public int getLabelSensor()
	{
		return super.getLabelSensor();
	}

	/**
	 * Dets the print method to either thermal transfer or direct thermal.
	 * @param printMethod : Print method
	 * @return Return value
	 */
	public int setPrintMethod(int printMethod)
	{
		return super.setPrintMethod(printMethod);
	}
	/**
	 * Gets the print method to either thermal transfer or direct thermal.
	 * @return Print method
	 */
	public int getPrintMethod()
	{
		return super.getPrintMethod();
	}

	/**
	 * Sets the sensor to use for the models which have multiple paper sensors, front and rear.
	 * @param sensorLocation : Sensor location
	 * @return Return value
	 */
	public int setSensorLocation(int sensorLocation)
	{
		return super.setSensorLocation(sensorLocation);
	}

	/**
	 * Gets the sensor to use for the models which have multiple paper sensors, front and rear.
	 * @return Sensor location
	 */
	public int getSensorLocation()
	{
		return super.getSensorLocation();
	}

	/**
	 * Shows the printer status if the interpreter is processing commands.
	 * @return Command interpreter in action
	 */
	public int getCommandInterpreterInAction()
	{
		return super.getCommandInterpreterInAction();
	}

	/**
	 * Shows the printer status if there is a paper error.
	 * @return Paper error
	 */
	public int getPaperError()
	{
		return super.getPaperError();
	}

	/**
	 * Shows the printer status if there is a ribbon end error.
	 * @return Ribbon end
	 */
	public int getRibbonEnd()
	{
		return super.getRibbonEnd();
	}

	/**
	 * Shows the status if the printer is processing batch print jobs.
	 * @return Batch processing
	 */
	public int getBatchProcessing()
	{
		return super.getBatchProcessing();
	}

	/**
	 * Shows the status if the printer is currently printing.
	 * @return Printing
	 */
	public int getPrinting()
	{
		return super.getPrinting();
	}

	/**
	 * Shows the status if the printer is in the pause mode.
	 * @return Pause
	 */
	public int getPause()
	{
		return super.getPause();
	}

	/**
	 * Shows the status if the printer is in the wait for peeling status.
	 * @return Waiting for peeling
	 */
	public int getWaitingForPeeling()
	{
		return super.getWaitingForPeeling();
	}
}
